@@ -3,8 +3,8 @@ import os
 import logging
 import requests
 import json
-from utils import retry
-from errors import GoogleApiError
+from .utils import retry
+from .errors import GoogleApiError
 
 
 class APIRequest(object):
@@ -34,11 +34,11 @@ class APIRequest(object):
 
     def _read_credential_file(self):
         if os.path.isfile(self._credential_path):
-            with open(self._credential_path, 'rb') as fin:
+            with open(self._credential_path, 'r') as fin:
                 self._credential.update(json.load(fin))
 
     def _save_credential_file(self):
-        with open(self._credential_path, 'wb') as f:
+        with open(self._credential_path, 'w') as f:
             json.dump(self._credential, f, indent=2)
 
     def _is_failed_status_code(self, status_code):
@@ -215,8 +215,7 @@ class APIRequest(object):
                 try:
                     error = resp.json().get('error', {})
                 except:
-                    print resp.content
-                    raise
+                    pass
                 if error.get('code') == 403 and \
                    error.get('errors')[0].get('reason') \
                    in ['rateLimitExceeded', 'userRateLimitExceeded']:
@@ -294,7 +293,7 @@ class APIRequest(object):
             self._error['reason'] = 'No resumable url {0}'.format(
                 resp.headers)
             return None
-        if isinstance(fp, file):
+        if hasattr(fp, 'read'):
             resp = self._api_request(
                 'POST',
                 resumable_url,
@@ -344,6 +343,7 @@ class APIRequest(object):
                               file_id,
                               fp,
                               headers={},
+                              body=None,
                               etag=None,
                               verify=True):
         """Create a file.
@@ -358,12 +358,16 @@ class APIRequest(object):
         :type fp:
             `file object` or `unicode`.
 
-
         :param headers:
             Request headers.
         :type headers:
             `dict`.
 
+        :param body:
+            Request body.
+        :type body:
+            `dict`.
+
         :param etag:
             (Optional) to be append to If-Match.
         :type etag:
@@ -387,6 +391,10 @@ class APIRequest(object):
                 headers = self._default_headers
             if etag:
                 headers.update({'If-Match': etag})
+            if body is not None:
+                data = json.dumps(body)
+            else:
+                data = None
             resp = self._api_request(
                 'PUT',
                 ''.join(
@@ -394,6 +402,7 @@ class APIRequest(object):
                 session=req,
                 params={'uploadType': 'resumable'},
                 headers=headers,
+                data=data,
                 verify=verify)
 
             self._logger.info(u'%d', resp.status_code)
@@ -427,7 +436,7 @@ class APIRequest(object):
                 break
         # update content
         while True:
-            if isinstance(fp, file):
+            if hasattr(fp, 'read'):
                 resp = self._api_request(
                     'PUT',
                     resumable_url,
